@@ -20,6 +20,7 @@
 #ifndef DATAXFER
 #define DATAXFER
 
+#include "utils.h"
 #include "controller.h"
 
 #ifdef USE_UUCP_LOCKING
@@ -40,11 +41,6 @@ extern int uucp_locking_enabled;
 
 #endif /* linux */
 
-struct absout {
-    int (*out)(struct absout *e, const char *str, ...);
-    void *data;
-};
-
 /* Create a port given the criteria. */
 int portconfig(struct absout *eout,
 	       char *portnum,
