@@ -25,7 +25,7 @@
 /* The default rfc2217 signature if none is provided. */
 extern char *rfc2217_signature;
 
-extern selector_t *ser2net_sel;
+extern struct selector_s *ser2net_sel;
 
 extern int ser2net_debug;
 extern int ser2net_debug_level;
